<?php
namespace Drupal\idealyzer\Controller;

use Drupal\Core\Controller\ControllerBase;

class ResultController extends ControllerBase {

    public function displayResults() {
        $data = \Drupal::state()->get('idealyzer.api_response', []);
        $build = [
            '#type' => 'markup',
            '#markup' => $this->t('No data available.'),
        ];

        if (!empty($data['items'])) {
            $processedItems = $this->parseItems($data['items']);
            // Create a render array for a table to display the items.
            $build = [
                '#type' => 'table',
                '#header' => $this->getTableHeaders(),
                '#rows' => $this->formatRowsForTable($processedItems),
                '#empty' => $this->t('No scan results found.'),
            ];
        }

        return $build;
    }

    private function parseItems($items) {
        $parsedItems = [];

        foreach ($items as $item) {
            $parsedItem = [];
            foreach ($item as $key => $value) {
                $parsedItem[$key] = $this->formatValue($value);
            }
            $parsedItems[] = $parsedItem;
        }

        return $parsedItems;
    }

    private function formatValue($value) {
        if (is_array($value)) {
            $formattedArray = [];
            foreach ($value as $subKey => $subValue) {
                $formattedArray[] = is_numeric($subKey) ? $this->formatValue($subValue) : $subKey . ': ' . $this->formatValue($subValue);
            }
            return implode(', ', $formattedArray);
        }
        return $value;
    }

    private function getTableHeaders() {
        return ['Field', 'Value'];
    }

    private function formatRowsForTable($processedItems) {
        $rows = [];
        foreach ($processedItems as $item) {
            foreach ($item as $key => $value) {
                $rows[] = [$key, $value];
            }
        }
        return $rows;
    }
}
