<?php

namespace Drupal\idealyzer\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\idealyzer\Service\SiteScannerService;

class SiteScannerForm extends FormBase {

  protected $siteScanner;

  public function __construct(SiteScannerService $siteScanner) {
    $this->siteScanner = $siteScanner;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('idealyzer.site_scanner')
    );
  }

  public function getFormId() {
    return 'idealyzer_site_scanner_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['url'] = [
        '#type' => 'textfield',
        '#title' => $this->t('URL to scan'),
        '#description' => $this->t('Enter the URL you wish to scan. Only the domain or subdomain should be included, e.g., "gsa.gov" or "subdomain.gsa.gov".'),
        '#required' => TRUE,
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
        '#type' => 'submit',
        '#value' => $this->t('Scan'),
    ];

    $form['#validate'][] = '::validateDomain';  // Add this line to include custom validation

    return $form;
}

/**
 * Validates the domain input to ensure proper formatting.
 */
public function validateDomain(array &$form, FormStateInterface $form_state) {
    $urlInput = $form_state->getValue('url');
    try {
        // Use PHP's filter_var to validate the URL
        if (filter_var($urlInput, FILTER_VALIDATE_URL) === FALSE) {
            // Try prepending http:// for parsing purposes if the URL does not validate
            $urlInput = "http://" . $urlInput;
        }

        // Parse URL to extract host part
        $host = parse_url($urlInput, PHP_URL_HOST);
        $host = $host ?: $urlInput;  // If the URL is still incorrect, use input directly

        // Use a regular expression to extract only the domain or subdomain
        if (preg_match('/(?P<domain>[a-zA-Z0-9.-]+\.[a-zA-Z]{2,})$/', $host, $matches)) {
            $domain = $matches['domain'];
            $form_state->setValue('url', $domain);
        } else {
            // If no domain found, set an error
            $form_state->setErrorByName('url', $this->t('Please enter a valid URL or domain.'));
        }
    } catch (\Exception $e) {
        $form_state->setErrorByName('url', $this->t('Invalid URL format.'));
    }
}


  public function submitForm(array &$form, FormStateInterface $form_state) {
      $url = $form_state->getValue('url');
      $result = $this->siteScanner->fetchData($url);
  
      if ($result['success']) {
          // Store the response data temporarily in the state system
          \Drupal::state()->set('idealyzer.api_response', $result['data']);
  
          // Redirect to a custom result page
          $form_state->setRedirect('idealyzer.display_results');
      } else {
          $this->messenger()->addError($this->t('Scan failed: @error', ['@error' => $result['error']]));
      }
  }
  

}
