<?php

namespace Drupal\idealyzer\Service;

use Drupal\Component\Serialization\Json;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\GuzzleException;

class SiteScannerService {
  protected $httpClient;
  protected $configFactory;

  public function __construct(Client $httpClient, $configFactory) {
    $this->httpClient = $httpClient;
    $this->configFactory = $configFactory;
  }

  /**
   * Fetches data from the Site Scanning API.
   *
   * @param string $url The URL of the site to scan.
   * @return array The response data or error message.
   */
  public function fetchData($url, $page = 1, $limit = 10) {
    $apiKey = $this->getApiKey();
    try {
        $response = $this->httpClient->request('GET', 'https://api.gsa.gov/technology/site-scanning/v1/websites', [
            'query' => [
                'target_url_domain' => $url,
                'api_key' => $apiKey,
                'page' => $page,
                'limit' => $limit
            ]
        ]);

        if ($response->getStatusCode() === 200) {
            return [
                'success' => true,
                'data' => Json::decode($response->getBody()->getContents()),
                'links' => $response->getHeader('Link')  // Capture pagination links if provided
            ];
        }
    } catch (GuzzleException $e) {
        watchdog_exception('idealyzer', $e);
        return [
            'success' => false,
            'error' => $e->getMessage()
        ];
    }

    return [
        'success' => false,
        'error' => t('Unknown error occurred.')
    ];
}



  /**
 * Retrieves the stored API key from configuration.
 *
 * @return string The API key.
 */
protected function getApiKey() {
    // Retrieve the actual API key from the configuration.
    return $this->configFactory->get('idealyzer.settings')->get('api_key');
}

  
}
